==> k3d_0.5.12.0.orig.tar.gz: k3d-0.5.12.0/k3dsdk/icamera_animation_render_engine.h <==
#ifndef K3DSDK_ICAMERA_ANIMATION_RENDER_ENGINE_H
#define K3DSDK_ICAMERA_ANIMATION_RENDER_ENGINE_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\author Tim Shead (tshead@k-3d.com)
*/

#include "iunknown.h"

namespace boost { namespace filesystem { class path; } }

namespace k3d
{

class icamera;
	
/// Abstract interface implemented by objects that can render a sequence of still images using a camera
class icamera_animation_render_engine :
	public virtual iunknown
{
public:
	virtual bool render_camera_animation(icamera& Camera, const boost::filesystem::path& OutputImages, const bool ViewCompletedImages) = 0;

protected:
	icamera_animation_render_engine() {}
	icamera_animation_render_engine(const icamera_animation_render_engine&) {}
	icamera_animation_render_engine& operator = (const icamera_animation_render_engine&) { return *this; }
	virtual ~icamera_animation_render_engine() {}
};

} // namespace k3d

#endif // K3DSDK_ICAMERA_ANIMATION_RENDER_ENGINE_H

==> k3d_0.6.7.0.orig.tar.gz: k3d-0.6.7.0/k3dsdk/icamera_animation_render_engine.h <==
#ifndef K3DSDK_ICAMERA_ANIMATION_RENDER_ENGINE_H
#define K3DSDK_ICAMERA_ANIMATION_RENDER_ENGINE_H

// K-3D
// Copyright (c) 1995-2007, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
	\author Tim Shead (tshead@k-3d.com)
*/

#include "iunknown.h"

namespace k3d
{

class icamera;
class file_range;
	
/// Abstract interface implemented by objects that can render a sequence of still images using a camera
class icamera_animation_render_engine :
	public virtual iunknown
{
public:
	virtual bool render_camera_animation(icamera& Camera, const file_range& OutputImages, const bool ViewCompletedImages) = 0;

protected:
	icamera_animation_render_engine() {}
	icamera_animation_render_engine(const icamera_animation_render_engine&) {}
	icamera_animation_render_engine& operator = (const icamera_animation_render_engine&) { return *this; }
	virtual ~icamera_animation_render_engine() {}
};

} // namespace k3d

#endif // K3DSDK_ICAMERA_ANIMATION_RENDER_ENGINE_H
